@@ -657,24 +657,14 @@ or empty VCALENDAR component"); */
     }
     span.start = icaltime_as_timet_with_zone(start, icaltimezone_get_utc_timezone());
 
-    /* The end time could be specified as either a DTEND or a DURATION */
+    /* The end time could be specified as either a DTEND, a DURATION, or be missing */
     /* icalcomponent_get_dtend takes care of these cases. */
     end = icalcomponent_get_dtend(comp);
-    if (icaltime_is_null_time(end)) {
-        if (!icaltime_is_date(start)) {
-            /* If dtstart is a DATE-TIME and there is no DTEND nor DURATION
-               it takes no time */
-            span.start = 0;
-            return span;
-        } else {
-            end = start;
-        }
-    }
 
     span.end = icaltime_as_timet_with_zone(end, icaltimezone_get_utc_timezone());
     if (icaltime_is_date(start)) {
         /* Until the end of the day */
-        span.end += 60 * 60 * 24 - 1;
+        span.end -= 1;
     }
 
     return span;
@@ -822,16 +812,9 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     if (icaltime_is_null_time(dtstart))
         return;
 
-    /* The end time could be specified as either a DTEND or a DURATION */
+    /* The end time could be specified as either a DTEND, a DURATION or be missing */
     /* icalcomponent_get_dtend takes care of these cases. */
     dtend = icalcomponent_get_dtend(comp);
-    if (icaltime_is_null_time(dtend) && icaltime_is_date(dtstart)) {
-        /* No DTEND or DURATION and DTSTART is DATE - duration is 1 day */
-        struct icaldurationtype dur = icaldurationtype_null_duration();
-
-        dur.days = 1;
-        dtend = icaltime_add(dtstart, dur);
-    }
 
     /* Now set up the base span for this item, corresponding to the
        base DTSTART and DTEND */
@@ -1354,13 +1337,26 @@ struct icaltimetype icalcomponent_get_dtstart(icalcomponent *comp)
 struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
-    icalproperty *end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
-    icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
-    struct icaltimetype ret = icaltime_null_time();
+    const icalcomponent_kind kind = icalcomponent_isa(inner);
+    icalproperty *end_prop, *dur_prop;
+    struct icaltimetype ret;
 
-    if (end_prop != 0) {
+    switch(kind) {
+    case ICAL_VAVAILABILITY_COMPONENT:
+    case ICAL_VEVENT_COMPONENT:
+    case ICAL_VFREEBUSY_COMPONENT:
+    case ICAL_XAVAILABLE_COMPONENT:
+        break;
+    default:
+        return icaltime_null_time();
+    }
+
+    end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
+    dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
+
+    if (end_prop != 0 && dur_prop == 0) {
         ret = icalproperty_get_datetime_with_component(end_prop, comp);
-    } else if (dur_prop != 0) {
+    } else if (end_prop == 0 && dur_prop != 0) {
 
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
         struct icaldurationtype duration;
@@ -1373,6 +1369,23 @@ struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp)
         }
 
         ret = icaltime_add(start, duration);
+    } else if (end_prop == 0 && dur_prop == 0) {
+        if (kind == ICAL_VEVENT_COMPONENT) {
+            struct icaltimetype start = icalcomponent_get_dtstart(inner);
+            if (icaltime_is_date(start)) {
+                struct icaldurationtype duration = icaldurationtype_null_duration();
+                duration.days = 1;
+                ret = icaltime_add(start, duration);
+            } else {
+                ret = start;
+            }
+        } else {
+            ret = icaltime_null_time();
+        }
+    } else {
+        /* Error, both duration and dtend have been specified */
+        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
+        ret = icaltime_null_time();
     }
 
     return ret;
@@ -1423,12 +1436,32 @@ void icalcomponent_set_duration(icalcomponent *comp, struct icaldurationtype v)
 struct icaldurationtype icalcomponent_get_duration(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
+    const icalcomponent_kind kind = icalcomponent_isa(inner);
+    icalproperty *end_prop, *dur_prop;
+    struct icaltimetype end;
+    struct icaldurationtype ret;
 
-    icalproperty *end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
+    switch(kind) {
+    case ICAL_VAVAILABILITY_COMPONENT:
+    case ICAL_VEVENT_COMPONENT:
+    case ICAL_XAVAILABLE_COMPONENT:
+        end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
+        if (end_prop) {
+            end = icalcomponent_get_dtend(inner);
+        }
+        break;
+    case ICAL_VTODO_COMPONENT:
+        end_prop = icalcomponent_get_first_property(inner, ICAL_DUE_PROPERTY);
+        if (end_prop) {
+            end = icalcomponent_get_due(inner);
+        }
+        break;
+    default:
+        /* The libical API is used incorrectly */
+        return icaldurationtype_null_duration();
+    }
 
-    icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
-
-    struct icaldurationtype ret = icaldurationtype_null_duration();
+    dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
 
     if (dur_prop != 0 && end_prop == 0) {
         ret = icalproperty_get_duration(dur_prop);
@@ -1437,13 +1470,19 @@ struct icaldurationtype icalcomponent_get_duration(icalcomponent *comp)
         /**
          * FIXME
          * We assume DTSTART and DTEND are not in different time zones.
-         * Does the standard actually guarantee this?
+         * The standard actually allows different time zones.
          */
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
-        struct icaltimetype end = icalcomponent_get_dtend(inner);
 
         ret = icaltime_subtract(end, start);
+    } else if (end_prop == 0 && dur_prop == 0) {
+        struct icaltimetype start = icalcomponent_get_dtstart(inner);
+        ret = icaldurationtype_null_duration();
+        if (kind == ICAL_VEVENT_COMPONENT && icaltime_is_date(start)) {
+            ret.days = 1;
+        }
     } else {
+        ret = icaldurationtype_null_duration();
         /* Error, both duration and dtend have been specified */
         icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
     }
@@ -2343,6 +2382,7 @@ void icalcomponent_set_due(icalcomponent *comp, struct icaltimetype v)
         icalcomponent_add_property(inner, due_prop);
     } else if (due_prop != 0) {
         icalproperty_set_due(due_prop, v);
+        icalproperty_remove_parameter_by_kind(due_prop, ICAL_TZID_PARAMETER);
     } else if (dur_prop != 0) {
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
 
@@ -2358,6 +2398,12 @@ void icalcomponent_set_due(icalcomponent *comp, struct icaltimetype v)
     }
 }
 
+static int strcmpsafe(const char *a, const char *b)
+{
+    return strcmp((a == NULL ? "" : a),
+                  (b == NULL ? "" : b));
+}
+
 static int prop_compare(void *a, void *b)
 {
     icalproperty *p1 = (icalproperty*) a;
@@ -2373,8 +2419,8 @@ static int prop_compare(void *a, void *b)
         }
 
         if (r == 0) {
-            r = strcmp(icalproperty_get_value_as_string(p1),
-                       icalproperty_get_value_as_string(p2));
+            r = strcmpsafe(icalproperty_get_value_as_string(p1),
+                           icalproperty_get_value_as_string(p2));
         }
     }
 
