@@ -83,7 +83,11 @@ int icalbdbset_init_dbenv(char *db_env_dir,
 
     flags = (u_int32_t) (DB_INIT_LOCK | DB_INIT_TXN | DB_CREATE | DB_THREAD |
                          DB_RECOVER | DB_INIT_LOG | DB_INIT_MPOOL);
+#if defined(_WIN32) //krazy:exclude=cpp
+    ret = ICAL_DB_ENV->open(ICAL_DB_ENV, db_env_dir, flags, 0 /*ignored on Windows*/);
+#else
     ret = ICAL_DB_ENV->open(ICAL_DB_ENV, db_env_dir, flags, S_IRUSR | S_IWUSR);
+#endif
 
     if (ret) {
         /*char *foo = db_strerror(ret); */
@@ -1271,7 +1275,7 @@ icalsetiter icalbdbset_begin_component(icalset *set, icalcomponent_kind kind,
     /* if there is a gauge, the first matched component is returned */
     while (comp != 0) {
 
-        /* check if it is a recurring component and with guage expand, if so
+        /* check if it is a recurring component and with gauge expand, if so
          * we need to add recurrence-id property to the given component */
         rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
         g = icalgauge_get_expand(gauge);
