@@ -125,19 +125,18 @@
 /*  FILE: icalssyacc.y                                                     */
 /*  CREATOR: eric 08 Aug 2000                                              */
 /*                                                                         */
-/*  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>             */
-/*      http://www.softwarestudio.org                                      */
+/*  (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>             */
 /*                                                                         */
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of either:                                           */
 /*                                                                         */
 /*    The LGPL as published by the Free Software Foundation, version       */
-/*    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html         */
+/*    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html         */
 /*                                                                         */
 /*  Or:                                                                    */
 /*                                                                         */
 /*    The Mozilla Public License Version 2.0. You may obtain a copy of     */
-/*    the License at http://www.mozilla.org/MPL/                           */
+/*    the License at https://www.mozilla.org/MPL/                           */
 /*                                                                         */
 /* The Original Code is eric. The Initial Developer of the Original        */
 /* Code is Eric Busboom                                                    */
@@ -341,7 +340,7 @@ YYID (i)
 #  ifndef YYSTACK_ALLOC_MAXIMUM
 #   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
 #  endif
-#  if (defined __cplusplus && ! defined _STDLIB_H \
+#  if (defined __cplusplus || defined __CYGWIN__ && ! defined _STDLIB_H \
        && ! ((defined YYMALLOC || defined malloc) \
              && (defined YYFREE || defined free)))
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
